pub struct Diagnostic {
pub code: DiagnosticCode,
pub span: Span,
pub severity: DiagnosticSeverity,
pub message: String,
}Expand description
Diagnostic entry emitted by markdown analysis.
Fields
code: DiagnosticCodeStable diagnostic code identifier.
span: SpanSource span where the issue applies.
severity: DiagnosticSeveritySeverity level.
message: StringUser-facing diagnostic message.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub fn code_id(&self) -> &'static str
pub fn code_id(&self) -> &'static str
Stable external code id from catalog (e.g. MD103) for this diagnostic.
Sourcepub fn fix_suggestion(&self) -> &'static str
pub fn fix_suggestion(&self) -> &'static str
Stable quick fix suggestion associated with this diagnostic code.
Sourcepub fn catalog_entry(&self) -> Option<&'static DiagnosticsCatalogEntry>
pub fn catalog_entry(&self) -> Option<&'static DiagnosticsCatalogEntry>
Optional embedded catalog entry for this diagnostic.
Sourcepub fn title_resolved(&self) -> Option<&'static str>
pub fn title_resolved(&self) -> Option<&'static str>
Human title from embedded catalog if present.
Sourcepub fn description_resolved(&self) -> Option<&'static str>
pub fn description_resolved(&self) -> Option<&'static str>
Rich description from embedded catalog if present.
Sourcepub fn fix_suggestion_resolved(&self) -> Cow<'static, str>
pub fn fix_suggestion_resolved(&self) -> Cow<'static, str>
Resolve fix suggestion from embedded catalog when available, with a stable in-code fallback.
Sourcepub fn parse_error_at(position: Position, message: impl Into<String>) -> Self
pub fn parse_error_at(position: Position, message: impl Into<String>) -> Self
Build a parse-failure diagnostic anchored at a specific position.
Sourcepub fn parse_error(message: impl Into<String>) -> Self
pub fn parse_error(message: impl Into<String>) -> Self
Build a parse-failure diagnostic at a safe default location (1:1).