Module cm_paragraph_parser

Module cm_paragraph_parser 

CommonMark paragraph parser. Paragraph parser - converts grammar output to AST nodes with inline parsing

Handles conversion of paragraphs from grammar layer to parser AST, including recursive inline element parsing for emphasis, links, etc.

Functions

parse_paragraph
Parse a paragraph into an AST node with inline elements.