Shared block parser utilities.
Re-exports
pub use crate::parser::shared::opt_span;pub use crate::parser::shared::opt_span_range_inclusive as opt_span_range;pub use crate::parser::shared::to_parser_span;pub use crate::parser::shared::to_parser_span_range_inclusive as to_parser_span_range;pub use crate::parser::shared::GrammarSpan;
Functions
- dedent_
list_ item_ content - Dedent list item content by removing the specified indent width. This function is used to strip the list item indentation from nested content.