pub struct Span {
pub start: Position,
pub end: Position,
}Expand description
A span representing a range in the source document.
Spans are inclusive of the start position and exclusive of the end position. This matches CommonMark and most parser conventions.
Example
For the text “bold”:
start: Position at the first ‘*’end: Position after the last ‘*’ (one past the last character)
Multi-line Spans
For multi-line content like code blocks, for example a fenced Rust code block, the inner code might look like:
fn main() {
}start.line: Line of opening backticksend.line: Line after closing backticks- Columns are byte offsets within their respective lines
Fields
start: PositionStart position (inclusive)
end: PositionEnd position (exclusive)
Implementations
Sourceimpl Span
impl Span
Sourcepub fn new(start: Position, end: Position) -> Self
pub fn new(start: Position, end: Position) -> Self
Create a new span from inclusive start and exclusive end positions.
Sourcepub fn start_line_offset(&self) -> usize
pub fn start_line_offset(&self) -> usize
Return the absolute byte offset of the start of the span’s first line.
This is a convenience wrapper around Position::line_start_offset for
the span’s start position.
Sourcepub fn end_line_offset(&self) -> usize
pub fn end_line_offset(&self) -> usize
Return the absolute byte offset of the start of the span’s end line. Useful when expanding a span to include the whole end line.