pub struct MarkdownIntelligenceProvider { /* private fields */ }Expand description
In-process provider for editor intelligence features.
Implementations
Sourceimpl MarkdownIntelligenceProvider
impl MarkdownIntelligenceProvider
Sourcepub fn update_document(&mut self, document: Document)
pub fn update_document(&mut self, document: Document)
Replace the currently analyzed document.
Sourcepub fn highlights(&self, source: &str) -> Vec<Highlight>
pub fn highlights(&self, source: &str) -> Vec<Highlight>
Compute semantic highlights for the current document using source-aware markers.
Sourcepub fn diagnostics(&self) -> Vec<Diagnostic>
pub fn diagnostics(&self) -> Vec<Diagnostic>
Compute diagnostics for the current document.
Sourcepub fn diagnostics_with_options(
&self,
options: DiagnosticsOptions,
) -> Vec<Diagnostic>
pub fn diagnostics_with_options( &self, options: DiagnosticsOptions, ) -> Vec<Diagnostic>
Compute diagnostics for the current document using custom options.
Sourcepub fn hover(&self, position: Position) -> Option<HoverInfo>
pub fn hover(&self, position: Position) -> Option<HoverInfo>
Resolve hover information for a source position.
Sourcepub fn completions(&self, query: &str) -> Vec<CompletionItem>
pub fn completions(&self, query: &str) -> Vec<CompletionItem>
Get completion candidates for a query.