Shared utilities for inline parsers
This module provides helper functions used by all inline parser modules, primarily for converting between grammar spans and parser spans.
Re-exports
pub use crate::parser::shared::opt_span;pub use crate::parser::shared::opt_span_range;pub use crate::parser::shared::to_parser_span;pub use crate::parser::shared::to_parser_span_range;pub use crate::parser::shared::GrammarSpan;