Module position

Module position 

Position and span utilities.

Structs

Position
Position in a source document using multiple coordinate systems.
Span
A span representing a range in the source document.

Functions

compute_line_start_offset
Convenience helper: compute the absolute byte offset of the start of the given span’s starting line.